#version 120

// this is set for the base colour texture (unit 0)
uniform sampler2D tex;
// this is set to the spec map (texture unit 1)
uniform sampler2D spec;
// normal map set a texture unit 2
uniform sampler2D normalMap;
// array of light vectors passed from vert shader
varying vec3 lightVec[8];
// array of half vects from vert shader
varying vec3 halfVec[8];
// uv values passed from vert shader
varying vec2 vertUV;
// number of lights (passed from client program)
uniform int numLights;
// spec power passed from client program (or could use alpha of spec map if present)
uniform float specPower;

void main ()
{

// lookup normal from normal map, move from [0,1] to  [-1, 1] range, normalize
//vec3 normal = 2.0 * texture2D (normalMap, vertUV.st).rgb - 1.0;
vec3 normal=normalize( texture2D(normalMap, vertUV.st).xyz * 2.0 - 1.0);
// we need to flip the z as this is done in zBrush
normal.z = -normal.z;
// default material values to be accumulated
float lamberFactor;
vec4 diffuseMaterial = vec4(0.0);
vec4 diffuseLight  = vec4(0.0);
// compute specular lighting
vec4 specularMaterial=vec4(0.0) ;
vec4 specularLight=vec4(0.0) ;
float shininess ;

for (int i=0; i<3; ++i)
{
	lamberFactor= max (dot (lightVec[i], normal), 0.0) ;
	// so light is hitting use here calculate and accumulate values
	if (lamberFactor > 0.0)
	{
	  // get diffuse values from texture
		diffuseMaterial = texture2D (tex, vertUV.st);
		diffuseLight  = gl_LightSource[i].diffuse;
		// lookup spec from texture map
		specularMaterial =  texture2D(spec, vertUV.st)  ;

		specularLight = gl_LightSource[i].specular;
		// get the phong / blinn values
		shininess = pow (max (dot ( normal,halfVec[i]), 0.0), specPower);
		gl_FragColor +=	diffuseMaterial * diffuseLight * lamberFactor;
		gl_FragColor +=	specularMaterial * specularLight * shininess;
	}
}

}
