#version 120

/// @brief projection matrix passed in from camera class in main app
uniform mat4 projectionMatrix;
/// @brief View transform matrix passed in from camera class in main app
uniform mat4 ViewMatrix;
/// @brief Model transform matrix passed in from Transform Class in main app
uniform mat4 ModelMatrix;
/// the number of lights
uniform int numLights;
// first attribute the vertex values from our VAO
attribute vec3 inVert;
// second attribute the UV values from our VAO
attribute vec2 inUV;
// third attribute the  normals values from our VAO
attribute vec3 inNormal;
// forth attribute the Tangents values from our VAO
attribute vec3 inTangent;
// fith attribute the binormal values from our VAO
attribute vec3 inBinormal;
// we use this to pass the UV values to the frag shader
varying vec2 vertUV;
// an array of light Vectors to be passed to the frag shader
varying vec3 lightVec[8];
// an array of half (blinn) vectors to be passed to the frag shader
varying vec3 halfVec[8];

void main()
{
	// pre-calculate for speed we will use this a lot
	mat4 ModelView=ViewMatrix*ModelMatrix;

	// calculate the vertex position
	gl_Position = projectionMatrix*ModelView*vec4(inVert, 1.0);
	// pass the UV values to the frag shader
	vertUV=inUV.st;

	// now fill the array of light pos and half vectors for the avaliable lights
	for (int i=0; i<numLights; ++i)
	{
		vec3 vertexPosition = vec3(gl_Position.xyz);
		vec3 lightDir = normalize(gl_LightSource[i].position.xyz - vertexPosition);


		// transform light and half angle vectors by tangent basis
		// this is based on code from here
		//http://www.ozone3d.net/tutorials/bump_mapping.php
		lightVec[i].x = dot (lightDir, inTangent);
		lightVec[i].y = dot (lightDir, inBinormal);
		lightVec[i].z = dot (lightDir, inNormal);

		vec3 halfVector = normalize(vertexPosition + lightDir);
		halfVec[i].x = dot (halfVector, inTangent);
		halfVec[i].y = dot (halfVector, inBinormal);
		halfVec[i].z = dot (halfVector, inNormal);
	}

}
